% Auto-generated chapter 19 for abudawud
% Hadiths in this chapter: 43

\hadithdefcmd{abudawud}{2885}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ زِيَادٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ رَافِعٍ التَّنُوخِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعِلْمُ ثَلاَثَةٌ وَمَا سِوَى ذَلِكَ فَهُوَ فَضْلٌ آيَةٌ مُحْكَمَةٌ أَوْ سُنَّةٌ قَائِمَةٌ أَوْ فَرِيضَةٌ عَادِلَةٌ ‏"‏ ‏.‏\hadithno{2885}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: Knowledge has three categories; anything else is extra; a precise verse, or an established sunnah (practice), or a firm obligatory duty}}
\hadithdefcmd{abudawud}{2886}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ ابْنَ الْمُنْكَدِرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ مَرِضْتُ فَأَتَانِي النَّبِيُّ صلى الله عليه وسلم يَعُودُنِي هُوَ وَأَبُو بَكْرٍ مَاشِيَيْنِ وَقَدْ أُغْمِيَ عَلَىَّ فَلَمْ أُكَلِّمْهُ فَتَوَضَّأَ وَصَبَّهُ عَلَىَّ فَأَفَقْتُ فَقُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ أَصْنَعُ فِي مَالِي وَلِي أَخَوَاتٌ قَالَ فَنَزَلَتْ آيَةُ الْمَوَارِيثِ ‏\{‏ يَسْتَفْتُونَكَ قُلِ اللَّهُ يُفْتِيكُمْ فِي الْكَلاَلَةِ ‏\}‏ ‏.‏\hadithno{2886}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6723) Sahih Muslim (1616)}\hadithtrans{Narrated Jabir:I fell ill, and the Prophet (ﷺ) and Abu Bakr came to me on foot to visit me. As I was unconscious, I could not speak to him. He performed ablution and sprinkled water on me ; so I became conscious. I said: Messenger of Allah, how should I do in my property, as I have sisters? Thereafter the verse about inheritance was revealed: "They ask thee for legal decision. Say: Allah directs (thus) about those who leave no descendants or ascendants as heirs}}
\hadithdefcmd{abudawud}{2887}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا كَثِيرُ بْنُ هِشَامٍ، حَدَّثَنَا هِشَامٌ، - يَعْنِي الدَّسْتَوَائِيَّ - عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ اشْتَكَيْتُ وَعِنْدِي سَبْعُ أَخَوَاتٍ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَنَفَخَ فِي وَجْهِي فَأَفَقْتُ فَقُلْتُ يَا رَسُولَ اللَّهِ أَلاَ أُوصِي لأَخَوَاتِي بِالثُّلُثِ قَالَ ‏"‏ أَحْسِنْ ‏"‏ ‏.‏ قُلْتُ الشَّطْرَ قَالَ ‏"‏ أَحْسِنْ ‏"‏ ‏.‏ ثُمَّ خَرَجَ وَتَرَكَنِي فَقَالَ ‏"‏ يَا جَابِرُ لاَ أُرَاكَ مَيِّتًا مِنْ وَجَعِكَ هَذَا وَإِنَّ اللَّهَ قَدْ أَنْزَلَ فَبَيَّنَ الَّذِي لأَخَوَاتِكَ فَجَعَلَ لَهُنَّ الثُّلُثَيْنِ ‏"‏ ‏.‏ قَالَ فَكَانَ جَابِرٌ يَقُولُ أُنْزِلَتْ هَذِهِ الآيَةُ فِيَّ ‏\{‏ يَسْتَفْتُونَكَ قُلِ اللَّهُ يُفْتِيكُمْ فِي الْكَلاَلَةِ ‏\}‏ ‏.‏\hadithno{2887}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: I fell ill, and I had seven sisters. The Messenger of Allah (ﷺ) came to me and blew on my face. So I became conscious. I said: Messenger of Allah, may I not bequeath one-third of my property to my sisters? He replied: Do good. I asked: Half? He replied: Do good. He then went out and left me, and said: I do not think, Jabir, you will die of this disease. Allah has revealed (verses) and described the share of your sisters. He appointed two-thirds for them. Jabir used to say: This verse was revealed about me: "They ask thee for a legal decision. Say: Allah directs (thus) about those who leave no descendants or ascendants as heirs}}
\hadithdefcmd{abudawud}{2888}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ آخِرُ آيَةٍ نَزَلَتْ فِي الْكَلاَلَةِ ‏\{‏ يَسْتَفْتُونَكَ قُلِ اللَّهُ يُفْتِيكُمْ فِي الْكَلاَلَةِ ‏\}‏ ‏.‏\hadithno{2888}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4605) Sahih Muslim (1618)}\hadithtrans{Narrated Al-Bara' bin 'Azib:The last verse revealed about the decease who left no descendants or ascendants: "They ask thee for the legal decision. Say: Allah directs (thus) about those who leave no descendants or ascendants as heirs}}
\hadithdefcmd{abudawud}{2889}{حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، حَدَّثَنَا أَبُو بَكْرٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ يَسْتَفْتُونَكَ فِي الْكَلاَلَةِ فَمَا الْكَلاَلَةُ قَالَ ‏ "‏ تُجْزِيكَ آيَةُ الصَّيْفِ ‏"‏ ‏.‏ فَقُلْتُ لأَبِي إِسْحَاقَ هُوَ مَنْ مَاتَ وَلَمْ يَدَعْ وَلَدًا وَلاَ وَالِدًا قَالَ كَذَلِكَ ظَنُّوا أَنَّهُ كَذَلِكَ ‏.‏\hadithno{2889}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Al-Bara' ibn Azib: A man came to the Prophet (ﷺ) and said: Messenger of Allah, they ask thee for a legal decision about a kalalah. What is meant by kalalah? He replied: The verse revealed in summer is sufficient for you. I asked AbuIshaq: Does it mean a person who dies and leaves neither children nor father? He said: This is so. The people think it is so}}
\hadithdefcmd{abudawud}{2890}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي قَيْسٍ الأَوْدِيِّ، عَنْ هُزَيْلِ بْنِ شُرَحْبِيلَ الأَوْدِيِّ، قَالَ جَاءَ رَجُلٌ إِلَى أَبِي مُوسَى الأَشْعَرِيِّ وَسَلْمَانَ بْنِ رَبِيعَةَ فَسَأَلَهُمَا عَنِ ابْنَةٍ وَابْنَةِ ابْنٍ وَأُخْتٍ، لأَبٍ وَأُمٍّ فَقَالاَ لاِبْنَتِهِ النِّصْفُ وَلِلأُخْتِ مِنَ الأَبِ وَالأُمِّ النِّصْفُ وَلَمْ يُوَرِّثَا ابْنَةَ الاِبْنِ شَيْئًا وَأْتِ ابْنَ مَسْعُودٍ فَإِنَّهُ سَيُتَابِعُنَا فَأَتَاهُ الرَّجُلُ فَسَأَلَهُ وَأَخْبَرَهُ بِقَوْلِهِمَا فَقَالَ لَقَدْ ضَلَلْتُ إِذًا وَمَا أَنَا مِنَ الْمُهْتَدِينَ وَلَكِنِّي سَأَقْضِي فِيهَا بِقَضَاءِ النَّبِيِّ صلى الله عليه وسلم لاِبْنَتِهِ النِّصْفُ وَلاِبْنَةِ الاِبْنِ سَهْمٌ تَكْمِلَةُ الثُّلُثَيْنِ وَمَا بَقِيَ فَلِلأُخْتِ مِنَ الأَبِ وَالأُمِّ ‏.‏\hadithno{2890}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6736)}\hadithtrans{Narrated Huzail b. Shurahbil al-Awadi:A man came to Abu Musa al-Ash'ari and Salman b. Rabi'ah, and asked about a case where there were a daughter, a son's daughter and full sister. They replied: The daughter gets half and the full gets half. The son's daughter gets nothing. Go to Ibn Mas'ud and you will find that he agrees with me. So the man came to him and informed him about their opinion. He said: I would then be in error and not be one of those who are rightly guided. But I decide concerning the matter as the Messenger of Allah (ﷺ) did: The daughter gets half, and the son's daughter gets a share which complete thirds (i.e. gets a sixth), and what remain to the full sister}}
\hadithdefcmd{abudawud}{2891}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى جِئْنَا امْرَأَةً مِنَ الأَنْصَارِ فِي الأَسْوَاقِ فَجَاءَتِ الْمَرْأَةُ بِابْنَتَيْنِ لَهَا فَقَالَتْ يَا رَسُولَ اللَّهِ هَاتَانِ بِنْتَا ثَابِتِ بْنِ قَيْسٍ قُتِلَ مَعَكَ يَوْمَ أُحُدٍ وَقَدِ اسْتَفَاءَ عَمُّهُمَا مَالَهُمَا وَمِيرَاثَهُمَا كُلَّهُ فَلَمْ يَدَعْ لَهُمَا مَالاً إِلاَّ أَخَذَهُ فَمَا تَرَى يَا رَسُولَ اللَّهِ فَوَاللَّهِ لاَ تُنْكَحَانِ أَبَدًا إِلاَّ وَلَهُمَا مَالٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَقْضِي اللَّهُ فِي ذَلِكَ ‏"‏ ‏.‏ قَالَ وَنَزَلَتْ سُورَةُ النِّسَاءِ ‏\{‏ يُوصِيكُمُ اللَّهُ فِي أَوْلاَدِكُمْ ‏\}‏ الآيَةَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ادْعُوا لِيَ الْمَرْأَةَ وَصَاحِبَهَا ‏"‏ ‏.‏ فَقَالَ لِعَمِّهِمَا ‏"‏ أَعْطِهِمَا الثُّلُثَيْنِ وَأَعْطِ أُمَّهُمَا الثُّمُنَ وَمَا بَقِيَ فَلَكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ أَخْطَأَ بِشْرٌ فِيهِ إِنَّمَا هُمَا ابْنَتَا سَعْدِ بْنِ الرَّبِيعِ وَثَابِتُ بْنُ قَيْسٍ قُتِلَ يَوْمَ الْيَمَامَةِ ‏.‏\hadithno{2891}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: We went out with the Messenger of Allah (ﷺ) and came to a woman of the Ansar in al-Aswaf. The woman brought her two daughters, and said: Messenger of Allah, these are the daughters of Thabit ibn Qays who was killed as a martyr when he was with you at the battle of Uhud, their paternal uncle has taken all their property and inheritance, and he has not left anything for them. What do you think, Messenger of Allah? They cannot be married unless they have some property. The Messenger of Allah (ﷺ) said: Allah will decide regarding the matter. Then the verse of Surat an-Nisa was revealed: "Allah (thus) directs you as regards your children's (inheritance)." Messenger of Allah (ﷺ) said: Call to me the woman and her husband's brother. He then said to their paternal uncle: Give them two-thirds and their mother an eighth, and what remains is yours. Abu Dawud said: The narrator Bishr made a mistake. They were the daughters of Sa'd b. al-Rabi' for Thabit b. Qais was killed in the battle of Yamamah}}
\hadithdefcmd{abudawud}{2892}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي دَاوُدُ بْنُ قَيْسٍ، وَغَيْرُهُ، مِنْ أَهْلِ الْعِلْمِ عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ امْرَأَةَ، سَعْدِ بْنِ الرَّبِيعِ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ سَعْدًا هَلَكَ وَتَرَكَ ابْنَتَيْنِ ‏.‏ وَسَاقَ نَحْوَهُ قَالَ أَبُو دَاوُدَ وَهَذَا هُوَ الصَّوَابُ ‏.‏\hadithno{2892}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir bin ‘Abdullah : The wife of Sa'd b. al-Rabi said: Messenger of Allah, Sa'd died and left two daughters. He then narrated the rest of the tradition in a similar way. Abu Dawud said: This is the most correct tradition}}
\hadithdefcmd{abudawud}{2893}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنِي أَبُو حَسَّانَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، أَنَّ مُعَاذَ بْنَ جَبَلٍ، وَرَّثَ أُخْتًا وَابْنَةً فَجَعَلَ لِكُلِّ وَاحِدَةٍ مِنْهُمَا النِّصْفَ وَهُوَ بِالْيَمَنِ وَنَبِيُّ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ حَىٌّ ‏.‏\hadithno{2893}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6734)}\hadithtrans{Narrated Al-Aswad b. Yazid:Mu'adh b. Jabal gave shares of inheritance to a sister and a daughter. He gave each of them half. He was at Yemen while the Prophet (ﷺ) was alive}}
\hadithdefcmd{abudawud}{2894}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُثْمَانَ بْنِ إِسْحَاقَ بْنِ خَرَشَةَ، عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، أَنَّهُ قَالَ جَاءَتِ الْجَدَّةُ إِلَى أَبِي بَكْرٍ الصِّدِّيقِ تَسْأَلُهُ مِيرَاثَهَا فَقَالَ مَا لَكِ فِي كِتَابِ اللَّهِ تَعَالَى شَىْءٌ وَمَا عَلِمْتُ لَكِ فِي سُنَّةِ نَبِيِّ اللَّهِ صلى الله عليه وسلم شَيْئًا فَارْجِعِي حَتَّى أَسْأَلَ النَّاسَ ‏.‏ فَسَأَلَ النَّاسَ فَقَالَ الْمُغِيرَةُ بْنُ شُعْبَةَ حَضَرْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْطَاهَا السُّدُسَ ‏.‏ فَقَالَ أَبُو بَكْرٍ هَلْ مَعَكَ غَيْرُكَ فَقَامَ مُحَمَّدُ بْنُ مَسْلَمَةَ فَقَالَ مِثْلَ مَا قَالَ الْمُغِيرَةُ بْنُ شُعْبَةَ فَأَنْفَذَهُ لَهَا أَبُو بَكْرٍ ثُمَّ جَاءَتِ الْجَدَّةُ الأُخْرَى إِلَى عُمَرَ بْنِ الْخَطَّابِ رضى الله عنه تَسْأَلُهُ مِيرَاثَهَا فَقَالَ مَا لَكِ فِي كِتَابِ اللَّهِ تَعَالَى شَىْءٌ وَمَا كَانَ الْقَضَاءُ الَّذِي قُضِيَ بِهِ إِلاَّ لِغَيْرِكِ وَمَا أَنَا بِزَائِدٍ فِي الْفَرَائِضِ وَلَكِنْ هُوَ ذَلِكَ السُّدُسُ فَإِنِ اجْتَمَعْتُمَا فِيهِ فَهُوَ بَيْنَكُمَا وَأَيَّتُكُمَا خَلَتْ بِهِ فَهُوَ لَهَا ‏.‏\hadithno{2894}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Qabisah ibn Dhuwayb: A grandmother came to AbuBakr asking him for her share of inheritance. He said: There is nothing prescribed for you in Allah's Book, nor do I know anything for you in the Sunnah of the Prophet of Allah (ﷺ) Go home till I question the people. He then questioned the people, and al-Mughirah ibn Shu'bah said: I had been present with the Messenger of Allah (ﷺ) when he gave grandmother a sixth. AbuBakr said: Is there anyone with you? Muhammad ibn Maslamah stood and said the same as al-Mughirah ibn Shu'bah had said. So AbuBakr made it apply to her. Another grandmother came to Umar ibn al-Khattab asking him for her share of inheritance. He said: Nothing has been prescribed for you in Allah's Book. The decision made before you was made for a grandmother other than you. I am not going to add in the shares of inheritance; but it is that sixth. If there are two of you, it is shared between you, but whichever of you is the only one left gets it all}}
\hadithdefcmd{abudawud}{2895}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي رِزْمَةَ، أَخْبَرَنِي أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ أَبُو الْمُنِيبِ الْعَتَكِيُّ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَعَلَ لِلْجَدَّةِ السُّدُسَ إِذَا لَمْ تَكُنْ دُونَهَا أُمٌّ ‏.‏\hadithno{2895}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Buraydah: The Prophet (ﷺ) appointed a sixth to a grandmother if no mother is left to inherit before her}}
\hadithdefcmd{abudawud}{2896}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّ ابْنَ ابْنِي مَاتَ فَمَا لِي مِنْ مِيرَاثِهِ فَقَالَ ‏"‏ لَكَ السُّدُسُ ‏"‏ ‏.‏ فَلَمَّا أَدْبَرَ دَعَاهُ فَقَالَ ‏"‏ لَكَ سُدُسٌ آخَرُ ‏"‏ ‏.‏ فَلَمَّا أَدْبَرَ دَعَاهُ فَقَالَ ‏"‏ إِنَّ السُّدُسَ الآخَرَ طُعْمَةٌ ‏"‏ ‏.‏ قَالَ قَتَادَةُ فَلاَ يَدْرُونَ مَعَ أَىِّ شَىْءٍ وَرَّثَهُ ‏.‏ قَالَ قَتَادَةُ أَقَلُّ شَىْءٍ وَرِثَ الْجَدُّ السُّدُسَ ‏.‏\hadithno{2896}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Imran ibn Husayn: A man came to the Prophet (ﷺ) and said: My son has died; what do I receive from his estate? He replied: You receive a sixth. When he turned away he called him and said: You receive another sixth. When he turned away, he called him and said: The other sixth is an allowance (beyond what is due). Qatadah said: They (the Companions) did not know the heirs with whom he was given (a sixth). Qatadah said: The minimum share given to the grandfather was a sixth}}
\hadithdefcmd{abudawud}{2897}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، أَنَّ عُمَرَ، قَالَ أَيُّكُمْ يَعْلَمُ مَا وَرَّثَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْجَدَّ فَقَالَ مَعْقِلُ بْنُ يَسَارٍ أَنَا وَرَّثَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم السُّدُسَ ‏.‏ قَالَ مَعَ مَنْ قَالَ لاَ أَدْرِي ‏.‏ قَالَ لاَ دَرَيْتَ فَمَا تُغْنِي إِذًا ‏.‏\hadithno{2897}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Al-Hasan reported that Umar asked:Which of your knows what share the Messenger of Allah (ﷺ) had given to the grandfather from the estate? Ma'qil ibn Yasar said: The Messenger of Allah (ﷺ) gave him a sixth. He asked: Along with whom? He replied: I do not know. He said: You do not know; what is the use then?}}
\hadithdefcmd{abudawud}{2898}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، وَمَخْلَدُ بْنُ خَالِدٍ، - وَهَذَا حَدِيثُ مَخْلَدٍ وَهُوَ الأَشْبَعُ - قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ حَدَّثَنَا مَعْمَرٌ عَنِ ابْنِ طَاوُسٍ عَنْ أَبِيهِ عَنِ ابْنِ عَبَّاسٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْسِمِ الْمَالَ بَيْنَ أَهْلِ الْفَرَائِضِ عَلَى كِتَابِ اللَّهِ فَمَا تَرَكَتِ الْفَرَائِضُ فَلأَوْلَى ذَكَرٍ ‏"‏ ‏.‏\hadithno{2898}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6732) Sahih Muslim (1615)}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: Divide the property among those whose share have been prescribed in the Book of Allah, and what remains from the prescribed shares goes to the nearest male heirs}}
\hadithdefcmd{abudawud}{2899}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ بُدَيْلٍ، عَنْ عَلِيِّ بْنِ أَبِي طَلْحَةَ، عَنْ رَاشِدِ بْنِ سَعْدٍ، عَنْ أَبِي عَامِرٍ الْهَوْزَنِيِّ عَبْدِ اللَّهِ بْنِ لُحَىٍّ، عَنِ الْمِقْدَامِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ تَرَكَ كَلاًّ فَإِلَىَّ ‏"‏ ‏.‏ وَرُبَّمَا قَالَ ‏"‏ إِلَى اللَّهِ وَإِلَى رَسُولِهِ ‏"‏ ‏.‏ ‏"‏ وَمَنْ تَرَكَ مَالاً فَلِوَرَثَتِهِ وَأَنَا وَارِثُ مَنْ لاَ وَارِثَ لَهُ أَعْقِلُ لَهُ وَأَرِثُهُ وَالْخَالُ وَارِثُ مَنْ لاَ وَارِثَ لَهُ يَعْقِلُ عَنْهُ وَيَرِثُهُ ‏"‏ ‏.‏\hadithno{2899}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Miqdam al-Kindi: The Prophet (ﷺ) said: If anyone leaves a debt or a helpless family I shall be responsible-and sometimes the narrator said: Allah and His Apostle will be responsible-but if anyone leaves property, it goes to his heirs. I am the heirs of him who has none, paying blood-wit for him and inheriting from him; and a maternal uncle is the heir of him who has none, paying blood-wit for him and inheriting from him}}
\hadithdefcmd{abudawud}{2900}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، - فِي آخَرِينَ - قَالُوا حَدَّثَنَا حَمَّادٌ، عَنْ بُدَيْلٍ، - يَعْنِي ابْنَ مَيْسَرَةَ - عَنْ عَلِيِّ بْنِ أَبِي طَلْحَةَ، عَنْ رَاشِدِ بْنِ سَعْدٍ، عَنْ أَبِي عَامِرٍ الْهَوْزَنِيِّ، عَنِ الْمِقْدَامِ الْكِنْدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا أَوْلَى بِكُلِّ مُؤْمِنٍ مِنْ نَفْسِهِ فَمَنْ تَرَكَ دَيْنًا أَوْ ضَيْعَةً فَإِلَىَّ وَمَنْ تَرَكَ مَالاً فَلِوَرَثَتِهِ وَأَنَا مَوْلَى مَنْ لاَ مَوْلَى لَهُ أَرِثُ مَالَهُ وَأَفُكُّ عَانَهُ وَالْخَالُ مَوْلَى مَنْ لاَ مَوْلَى لَهُ يَرِثُ مَالَهُ وَيَفُكُّ عَانَهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الزُّبَيْدِيُّ عَنْ رَاشِدِ بْنِ سَعْدٍ عَنِ ابْنِ عَائِذٍ عَنِ الْمِقْدَامِ وَرَوَاهُ مُعَاوِيَةُ بْنُ صَالِحٍ عَنْ رَاشِدٍ قَالَ سَمِعْتُ الْمِقْدَامَ ‏.‏ قَالَ أَبُو دَاوُدَ يَقُولُ الضَّيْعَةُ مَعْنَاهُ عِيَالٌ ‏.‏\hadithno{2900}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Al-Miqdam al-Kindi: The Prophet (ﷺ) said: I am nearer to every believer than himself, so if anyone leaves a debt or a helpless family, I shall be responsible, but if anyone leaves property, it goes to his heirs. I am patron of him who has none, inheriting his property and freeing him from his liabilities. A maternal uncle is patron of him who has none, inheriting his property and freeing him from his liabilities. Abu Dawud said: da'iah means dependants or helpless family. Abu Dawud said: This tradition has been transmitted by al-Zubaidi from Rashid b. Sa'd from Ibn 'A'idh on the authority of al-Miqdam. It has also been transmitted by Mu'awiyah b. Salih from Rashid who said: I heard al-Miqdam (say)}}
\hadithdefcmd{abudawud}{2901}{حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ عَتِيقٍ الدِّمَشْقِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُبَارَكِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ يَزِيدَ بْنِ حُجْرٍ، عَنْ صَالِحِ بْنِ يَحْيَى بْنِ الْمِقْدَامِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَنَا وَارِثُ مَنْ لاَ وَارِثَ لَهُ أَفُكُّ عَانِيَهُ وَأَرِثُ مَالَهُ وَالْخَالُ وَارِثُ مَنْ لاَ وَارِثَ لَهُ يَفُكُّ عَانِيَهُ وَيَرِثُ مَالَهُ ‏"‏ ‏.‏\hadithno{2901}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Al-Miqdam: I heard the Messenger of Allah (ﷺ) say: I am the heirs of Him who has none, freeing him from his liabilities, and inheriting what he possesses. A maternal uncle is the heir of Him who has none, freeing him from his liabilities, and inheriting his property}}
\hadithdefcmd{abudawud}{2902}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ سُفْيَانَ، جَمِيعًا عَنِ ابْنِ الأَصْبَهَانِيِّ، عَنْ مُجَاهِدِ بْنِ وَرْدَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ مَوْلًى، لِلنَّبِيِّ صلى الله عليه وسلم مَاتَ وَتَرَكَ شَيْئًا وَلَمْ يَدَعْ وَلَدًا وَلاَ حَمِيمًا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَعْطُوا مِيرَاثَهُ رَجُلاً مِنْ أَهْلِ قَرْيَتِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ سُفْيَانَ أَتَمُّ وَقَالَ مُسَدَّدٌ قَالَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَا هُنَا أَحَدٌ مِنْ أَهْلِ أَرْضِهِ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ فَأَعْطُوهُ مِيرَاثَهُ ‏"‏ ‏.‏\hadithno{2902}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: A client of the Prophet (ﷺ) died and left some property, but he left no child or relative. The Messenger of Allah (ﷺ) said: Give what he has left to a man belonging to his village. Abu Dawud said: The tradition of Sufyan is more perfect. Musaddad said: Thereupon the Prophet (ﷺ) said: Is there anyone belonging to his land ? They replied: Yes. He said: Then give him what he has left}}
\hadithdefcmd{abudawud}{2903}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ الْكِنْدِيُّ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ جِبْرِيلَ بْنِ أَحْمَرَ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ فَقَالَ إِنَّ عِنْدِي مِيرَاثَ رَجُلٍ مِنَ الأَزْدِ وَلَسْتُ أَجِدُ أَزْدِيًّا أَدْفَعُهُ إِلَيْهِ ‏.‏ قَالَ ‏"‏ اذْهَبْ فَالْتَمِسْ أَزْدِيًّا حَوْلاً ‏"‏ ‏.‏ قَالَ فَأَتَاهُ بَعْدَ الْحَوْلِ فَقَالَ يَا رَسُولَ اللَّهِ لَمْ أَجِدْ أَزْدِيًّا أَدْفَعُهُ إِلَيْهِ ‏.‏ قَالَ ‏"‏ فَانْطَلِقْ فَانْظُرْ أَوَّلَ خُزَاعِيٍّ تَلْقَاهُ فَادْفَعْهُ إِلَيْهِ ‏"‏ ‏.‏ فَلَمَّا وَلَّى قَالَ ‏"‏ عَلَىَّ الرَّجُلَ ‏"‏ ‏.‏ فَلَمَّا جَاءَ قَالَ ‏"‏ انْظُرْ كُبْرَ خُزَاعَةَ فَادْفَعْهُ إِلَيْهِ ‏"‏ ‏.‏\hadithno{2903}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Buraydah ibn al-Hasib: A man came to the Messenger of Allah (ﷺ) and said: I have property left by a man of Azd. I do not find any man of Azd to give it to him. He said: Go and look for man of Azd for a year. He then came to him after one year and said: Messenger of Allah, I did not find any man of Azd to give it to him. He said: Look for a man of Khuza'ah whom you meet first and give it to him. When he turned away, he said; Call the man to me. When he came to him, he said: Look for the leading man of Khuza'ah and give it to him}}
\hadithdefcmd{abudawud}{2904}{حَدَّثَنَا الْحُسَيْنُ بْنُ أَسْوَدَ الْعِجْلِيُّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا شَرِيكٌ، عَنْ جِبْرِيلَ بْنِ أَحْمَرَ أَبِي بَكْرٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ مَاتَ رَجُلٌ مِنْ خُزَاعَةَ فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِمِيرَاثِهِ فَقَالَ ‏"‏ الْتَمِسُوا لَهُ وَارِثًا أَوْ ذَا رَحِمٍ ‏"‏ ‏.‏ فَلَمْ يَجِدُوا لَهُ وَارِثًا وَلاَ ذَا رَحِمٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْطُوهُ الْكُبْرَ مِنْ خُزَاعَةَ ‏"‏ ‏.‏ قَالَ يَحْيَى قَدْ سَمِعْتُهُ مَرَّةً يَقُولُ فِي هَذَا الْحَدِيثِ ‏"‏ انْظُرُوا أَكْبَرَ رَجُلٍ مِنْ خُزَاعَةَ ‏"‏ ‏.‏\hadithno{2904}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Buraydah ibn al-Hasib: A man of Khuza'ah died and his estate was brought to the Prophet (ﷺ). He said: Look for his heir or some relative. But they found neither heir nor relative. The Messenger of Allah (ﷺ) said: Give it to the leading man of Khuza'ah. The narrator Yahya said: Sometimes I heard him (al-Husayn ibn Aswad) say in this tradition: Look for the greatest man of Khuza'ah}}
\hadithdefcmd{abudawud}{2905}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ عَوْسَجَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، مَاتَ وَلَمْ يَدَعْ وَارِثًا إِلاَّ غُلاَمًا لَهُ كَانَ أَعْتَقَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَلْ لَهُ أَحَدٌ ‏"‏ ‏.‏ قَالُوا لاَ إِلاَّ غُلاَمًا لَهُ كَانَ أَعْتَقَهُ ‏.‏ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِيرَاثَهُ لَهُ ‏.‏\hadithno{2905}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: A man died leaving no heir but a slave whom he had emancipated. The Messenger of Allah (ﷺ) asked: Has he any heir? They replied: No, except a slave whom he had emancipated. The Messenger of Allah (ﷺ) assigned his estate to him (the emancipated slave)}}
\hadithdefcmd{abudawud}{2906}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنِي عُمَرُ بْنُ رُؤْبَةَ التَّغْلِبِيُّ، عَنْ عَبْدِ الْوَاحِدِ بْنِ عَبْدِ اللَّهِ النَّصْرِيِّ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَرْأَةُ تُحْرِزُ ثَلاَثَةَ مَوَارِيثَ عَتِيقَهَا وَلَقِيطَهَا وَوَلَدَهَا الَّذِي لاَعَنَتْ عَنْهُ ‏"‏ ‏.‏\hadithno{2906}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Wathilah ibn al-Asqa': The Prophet (ﷺ) said: A woman gets inheritance from the three following: one she has set free, a foundling, and her child about whom she has invoked a curse on herself if she was untrue in declaring he was not born out of wedlock}}
\hadithdefcmd{abudawud}{2907}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، وَمُوسَى بْنُ عَامِرٍ، قَالاَ حَدَّثَنَا الْوَلِيدُ، أَخْبَرَنَا ابْنُ جَابِرٍ، حَدَّثَنَا مَكْحُولٌ، قَالَ جَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِيرَاثَ ابْنِ الْمُلاَعِنَةِ لأُمِّهِ وَلِوَرَثَتِهَا مِنْ بَعْدِهَا ‏.‏\hadithno{2907}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Makhul: The Messenger of Allah (ﷺ) assigned the estate of a child of a woman about whom she had invoked a curse to her mother, and to her heirs after her}}
\hadithdefcmd{abudawud}{2908}{حَدَّثَنَا مُوسَى بْنُ عَامِرٍ، حَدَّثَنَا الْوَلِيدُ، أَخْبَرَنِي عِيسَى أَبُو مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ الْحَارِثِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{2908}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Amr bin Shu'aib:On his father's authority, said that his grandfather reported from the Prophet (ﷺ) something similar}}
\hadithdefcmd{abudawud}{2909}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ عَمْرِو بْنِ عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَرِثُ الْمُسْلِمُ الْكَافِرَ وَلاَ الْكَافِرُ الْمُسْلِمَ ‏"‏ ‏.‏\hadithno{2909}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4282، 4283) Sahih Muslim (1614)}\hadithtrans{Narrated Usamah b. Zaid:The Prophet (ﷺ) as saying: A Muslim may not inherit from an infidel nor an infidel from a Muslim}}
\hadithdefcmd{abudawud}{2910}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ عَمْرِو بْنِ عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَيْنَ تَنْزِلُ غَدًا فِي حَجَّتِهِ ‏.‏ قَالَ ‏"‏ وَهَلْ تَرَكَ لَنَا عَقِيلٌ مَنْزِلاً ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ نَحْنُ نَازِلُونَ بِخَيْفِ بَنِي كِنَانَةَ حَيْثُ تَقَاسَمَتْ قُرَيْشٌ عَلَى الْكُفْرِ ‏"‏ ‏.‏ يَعْنِي الْمُحَصَّبَ وَذَاكَ أَنَّ بَنِي كِنَانَةَ حَالَفَتْ قُرَيْشًا عَلَى بَنِي هَاشِمٍ أَنْ لاَ يُنَاكِحُوهُمْ وَلاَ يُبَايِعُوهُمْ وَلاَ يُئْوُوهُمْ ‏.‏ قَالَ الزُّهْرِيُّ وَالْخَيْفُ الْوَادِي ‏.‏\hadithno{2910}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3058) Sahih Muslim (1351)}\hadithtrans{Narrated Usamah b. Zaid:I said: Messenger of Allah, where will you stay tomorrow ? This (happened) during his Hajj. He replied: Has 'Aqil left any house for us ? He then said: We shall stay at the valley of Banu Kinarah where the Quraish took an oath on unbelief. This refers to al-Muhassab. The reason is that Banu Kinarah made an alliance with the Quraish against Banu Hashim that they would have no marital connections with them, nor will have commercial transactions with them, not will give them any refuge. Al-Zuhri said: Khalf means valley}}
\hadithdefcmd{abudawud}{2911}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ حَبِيبٍ الْمُعَلِّمِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَتَوَارَثُ أَهْلُ مِلَّتَيْنِ شَتَّى ‏"‏ ‏.‏\hadithno{2911}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: people of two different religions would not inherit from one another}}
\hadithdefcmd{abudawud}{2912}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَمْرِو بْنِ أَبِي حَكِيمٍ الْوَاسِطِيِّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، أَنَّ أَخَوَيْنِ، اخْتَصَمَا إِلَى يَحْيَى بْنِ يَعْمَرَ يَهُودِيٌّ وَمُسْلِمٌ فَوَرَّثَ الْمُسْلِمَ مِنْهُمَا وَقَالَ حَدَّثَنِي أَبُو الأَسْوَدِ أَنَّ رَجُلاً حَدَّثَهُ أَنَّ مُعَاذًا حَدَّثَهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الإِسْلاَمُ يَزِيدُ وَلاَ يَنْقُصُ ‏"‏ ‏.‏ فَوَرَّثَ الْمُسْلِمَ ‏.‏\hadithno{2912}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Jabal: I heard the Messenger of Allah (ﷺ) say: Islam increases and does not diminish. He, therefore, appointed a Muslim heir (of a non-Muslim)}}
\hadithdefcmd{abudawud}{2913}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ أَبِي حَكِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ أَبِي الأَسْوَدِ الدِّيلِيِّ، أَنَّ مُعَاذًا، أُتِيَ بِمِيرَاثِ يَهُودِيٍّ وَارِثُهُ مُسْلِمٌ بِمَعْنَاهُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2913}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif}\hadithtrans{Narrated Abu Al-Aswad al-Dili:Mu'adh bought the property of a Jew whose heir was a Muslim. He then narrated from the Prophet (ﷺ) to the same effect}}
\hadithdefcmd{abudawud}{2914}{حَدَّثَنَا حَجَّاجُ بْنُ أَبِي يَعْقُوبَ، حَدَّثَنَا مُوسَى بْنُ دَاوُدَ، حَدَّثَنَا مُحَمَّدُ بْنُ مُسْلِمٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي الشَّعْثَاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ كُلُّ قَسْمٍ قُسِمَ فِي الْجَاهِلِيَّةِ فَهُوَ عَلَى مَا قُسِمَ لَهُ وَكُلُّ قَسْمٍ أَدْرَكَهُ الإِسْلاَمُ فَهُوَ عَلَى قَسْمِ الإِسْلاَمِ ‏"‏ ‏.‏\hadithno{2914}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: An estate which was divided in pre-Islamic period may follow the division in force then, but any estate in Islamic times must follow the division laid down by Islam}}
\hadithdefcmd{abudawud}{2915}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ قُرِئَ عَلَى مَالِكٍ وَأَنَا حَاضِرٌ، قَالَ مَالِكٌ عَرَضَ عَلَىَّ نَافِعٌ عَنِ ابْنِ عُمَرَ، أَنَّ عَائِشَةَ، رضى الله عنها أُمَّ الْمُؤْمِنِينَ أَرَادَتْ أَنْ تَشْتَرِيَ جَارِيَةً تَعْتِقُهَا فَقَالَ أَهْلُهَا نَبِيعُكِهَا عَلَى أَنَّ وَلاَءَهَا لَنَا ‏.‏ فَذَكَرَتْ عَائِشَةُ ذَاكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ يَمْنَعُكِ ذَلِكَ فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{2915}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2169) Sahih Muslim (1504)}\hadithtrans{Narrated Ibn 'Umar:'Aishah, mother of believers (ra), intended to buy a slave-girl to set her free. Her people said: We shall sell her to you on one condition that we shall inherit from her. 'Aishah mentioned it to the Messenger of Allah (ﷺ). He said: That should not prevent you, for the right of inheritance belongs to the one who has set a person free}}
\hadithdefcmd{abudawud}{2916}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْوَلاَءُ لِمَنْ أَعْطَى الثَّمَنَ وَوَلِيَ النِّعْمَةَ ‏"‏ ‏.‏\hadithno{2916}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6754)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) as saying: The right of inheritance belongs to only to the one who paid the price (of the slave) and patronised him by doing an act of gratitude}}
\hadithdefcmd{abudawud}{2917}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ أَبِي الْحَجَّاجِ أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رِئَابَ بْنَ حُذَيْفَةَ، تَزَوَّجَ امْرَأَةً فَوَلَدَتْ لَهُ ثَلاَثَةَ غِلْمَةٍ فَمَاتَتْ أُمُّهُمْ فَوَرِثُوهَا رِبَاعَهَا وَوَلاَءَ مَوَالِيهَا وَكَانَ عَمْرُو بْنُ الْعَاصِ عَصَبَةَ بَنِيهَا فَأَخْرَجَهُمْ إِلَى الشَّامِ فَمَاتُوا فَقَدِمَ عَمْرُو بْنُ الْعَاصِ وَمَاتَ مَوْلًى لَهَا وَتَرَكَ مَالاً لَهُ فَخَاصَمَهُ إِخْوَتُهَا إِلَى عُمَرَ بْنِ الْخَطَّابِ فَقَالَ عُمَرُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَحْرَزَ الْوَلَدُ أَوِ الْوَالِدُ فَهُوَ لِعَصَبَتِهِ مَنْ كَانَ ‏"‏ ‏.‏ قَالَ فَكَتَبَ لَهُ كِتَابًا فِيهِ شَهَادَةُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَزَيْدِ بْنِ ثَابِتٍ وَرَجُلٍ آخَرَ فَلَمَّا اسْتُخْلِفَ عَبْدُ الْمَلِكِ اخْتَصَمُوا إِلَى هِشَامِ بْنِ إِسْمَاعِيلَ أَوْ إِلَى إِسْمَاعِيلَ بْنِ هِشَامٍ فَرَفَعَهُمْ إِلَى عَبْدِ الْمَلِكِ فَقَالَ هَذَا مِنَ الْقَضَاءِ الَّذِي مَا كُنْتُ أَرَاهُ ‏.‏ قَالَ فَقَضَى لَنَا بِكِتَابِ عُمَرَ بْنِ الْخَطَّابِ فَنَحْنُ فِيهِ إِلَى السَّاعَةِ ‏.‏\hadithno{2917}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather reported: Rabab ibn Hudhayfah married a woman and three sons were born to him from her. Their mother then died. They inherited her houses and had the right of inheritance of her freed slaves. Amr ibn al-'As was the agnate of her sons. He sent them to Syria where they died. Amr ibn al-'As then came. A freed slave of hers died and left some property. Her brothers disputed with him and brought the case to Umar ibn al-Khattab. Umar reported the Messenger of Allah (ﷺ) as saying: Whatever property a son or a father receives as an heir will go to his agnates, whoever they may be. He then wrote a document for him, witnessed by AbdurRahman ibn Awf, Zayd ibn Thabit and one other person. When AbdulMalik became caliph, they presented the case to Hisham ibn Isma'il or Isma'il ibn Hisham (the narrator is doubtful). He sent them to 'Abd al-Malik who said: This is the decision which I have already seen. The narrator said: So he ('Abd al-Malik) made the decision on the basis of the document of Umar ibn al-Khattab, and that is still with us till this moment}}
\hadithdefcmd{abudawud}{2918}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ الرَّمْلِيُّ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا يَحْيَى، - قَالَ أَبُو دَاوُدَ وَهُوَ ابْنُ حَمْزَةَ - عَنْ عَبْدِ الْعَزِيزِ بْنِ عُمَرَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَوْهَبٍ، يُحَدِّثُ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، - قَالَ هِشَامٌ عَنْ تَمِيمٍ الدَّارِيِّ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ ‏.‏ وَقَالَ يَزِيدُ - إِنَّ تَمِيمًا قَالَ يَا رَسُولَ اللَّهِ مَا السُّنَّةُ فِي الرَّجُلِ يُسْلِمُ عَلَى يَدَىِ الرَّجُلِ مِنَ الْمُسْلِمِينَ قَالَ ‏ "‏ هُوَ أَوْلَى النَّاسِ بِمَحْيَاهُ وَمَمَاتِهِ ‏"‏ ‏.‏\hadithno{2918}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{(Narrated Tamim ad-Dari: Tamim asked: Messenger of Allah), what is the sunnah about a man who accepts Islam by advice and persuasion of a Muslim? He replied: He is the nearest to him in life and in death}}
\hadithdefcmd{abudawud}{2919}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْوَلاَءِ وَعَنْ هِبَتِهِ ‏.‏\hadithno{2919}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2535) Sahih Muslim (1506)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) forbade selling or giving away the right to inheritance by a manumitted slave}}
\hadithdefcmd{abudawud}{2920}{حَدَّثَنَا حُسَيْنُ بْنُ مُعَاذٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ إِسْحَاقَ - عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَهَلَّ الْمَوْلُودُ وُرِّثَ ‏"‏ ‏.‏\hadithno{2920}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When an infant has raised its voice (and then dies), it will be treated as an heir}}
\hadithdefcmd{abudawud}{2921}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، رضى الله عنهما قَالَ ‏\{‏ وَالَّذِينَ عَقَدَتْ أَيْمَانُكُمْ فَآتُوهُمْ نَصِيبَهُمْ ‏\}‏ كَانَ الرَّجُلُ يُحَالِفُ الرَّجُلَ لَيْسَ بَيْنَهُمَا نَسَبٌ فَيَرِثُ أَحَدُهُمَا الآخَرَ فَنَسَخَ ذَلِكَ الأَنْفَالُ فَقَالَ تَعَالَى ‏\{‏ وَأُولُو الأَرْحَامِ بَعْضُهُمْ أَوْلَى بِبَعْضٍ ‏\}‏ ‏.‏\hadithno{2921}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Abbas:To those also, to whom your right hand was pledged, give their due portion. A man made an agreement with another man (in early days of Islam), and there was no relationship between the ; one of them inherited from the other. The following verse of Surat Al-Anfal abrogated it: "But kindred by blood have prior right against each other}}
\hadithdefcmd{abudawud}{2922}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي إِدْرِيسُ بْنُ يَزِيدَ، حَدَّثَنَا طَلْحَةُ بْنُ مُصَرِّفٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ ‏\{‏ وَالَّذِينَ عَقَدَتْ أَيْمَانُكُمْ فَآتُوهُمْ نَصِيبَهُمْ ‏\}‏ قَالَ كَانَ الْمُهَاجِرُونَ حِينَ قَدِمُوا الْمَدِينَةَ تُوَرِّثُ الأَنْصَارَ دُونَ ذَوِي رَحِمِهِ لِلأُخُوَّةِ الَّتِي آخَى رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُمْ فَلَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَلِكُلٍّ جَعَلْنَا مَوَالِيَ مِمَّا تَرَكَ ‏\}‏ قَالَ نَسَخَتْهَا ‏\{‏ وَالَّذِينَ عَقَدَتْ أَيْمَانُكُمْ فَآتُوهُمْ نَصِيبَهُمْ ‏\}‏ مِنَ النُّصْرَةِ وَالنَّصِيحَةِ وَالرِّفَادَةِ وَيُوصِي لَهُ وَقَدْ ذَهَبَ الْمِيرَاثُ ‏.‏\hadithno{2922}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4580)}\hadithtrans{Ibn 'Abbas explained the following Qur'anic verse :"To those also, to whom your right hand was pledged, give your portion." When the Emigrants came to Medina. they inherited from the Helpers without any blood-relationship with them for the brotherhood which the Messenger of Allah (ﷺ) established between them. When the following verse was revealed: "To (benefit) everyone we have appointed shares and heirs to property left by parent and relatives." it abrogated the verse: "To those also, to whom your right hand was pledged, give their due portion." This alliance was made for help, well wishing and cooperation. Now a legacy can be made for him. (The right to)inheritance was abolished}}
\hadithdefcmd{abudawud}{2923}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَعَبْدُ الْعَزِيزِ بْنُ يَحْيَى الْمَعْنَى، - قَالَ أَحْمَدُ - حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ ابْنِ إِسْحَاقَ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، قَالَ كُنْتُ أَقْرَأُ عَلَى أُمِّ سَعْدٍ بِنْتِ الرَّبِيعِ وَكَانَتْ يَتِيمَةً فِي حِجْرِ أَبِي بَكْرٍ فَقَرَأْتُ ‏\{‏ وَالَّذِينَ عَقَدَتْ أَيْمَانُكُمْ ‏\}‏ فَقَالَتْ لاَ تَقْرَأْ ‏\{‏ وَالَّذِينَ عَاقَدَتْ أَيْمَانُكُمْ ‏\}‏ وَلَكِنْ ‏\{‏ وَالَّذِينَ عَقَدَتْ أَيْمَانُكُمْ ‏\}‏ إِنَّمَا نَزَلَتْ فِي أَبِي بَكْرٍ وَابْنِهِ عَبْدِ الرَّحْمَنِ حِينَ أَبَى الإِسْلاَمَ فَحَلَفَ أَبُو بَكْرٍ أَلاَّ يُوَرِّثَهُ فَلَمَّا أَسْلَمَ أَمَرَ اللَّهُ تَعَالَى نَبِيَّهُ عَلَيْهِ السَّلاَمُ أَنْ يُؤْتِيَهُ نَصِيبَهُ ‏.‏ زَادَ عَبْدُ الْعَزِيزِ فَمَا أَسْلَمَ حَتَّى حُمِلَ عَلَى الإِسْلاَمِ بِالسَّيْفِ ‏.‏ قَالَ أَبُو دَاوُدَ مَنْ قَالَ ‏\{‏ عَقَدَتْ ‏\}‏ جَعَلَهُ حِلْفًا وَمَنْ قَالَ ‏\{‏ عَاقَدَتْ ‏\}‏ جَعَلَهُ حَالِفًا وَالصَّوَابُ حَدِيثُ طَلْحَةَ ‏\{‏ عَاقَدَتْ ‏\}‏ ‏.‏\hadithno{2923}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Dawud b. al-Husain: I used to learn the reading of the Qur'an from Umm Sa'd, daughter of al-Rabi'. She was an orphan in the guardianship of Abu Bakr. I read the Qur'anic verse "To those also to whom your right hand was pledged." She said: Do not read the verse; "To those also to whom your right hand was pledged." This was revealed about Abu Bakr and his son 'Abd al-Rahman when he refused to accept Islam. Abu Bakr took an oath that he would not give him a share from inheritance. When he embraced Islam Allah Most High commanded His Prophet (ﷺ) to give him the share. The narrator 'Abd al-Aziz added: He did not accept Islam until he was urged on Islam by sword. Abu Dawud said: He who narrated the word 'aqadat means a pact ; and he who narrated the word 'aaqadat means the party who made a pact. The correct is the tradition of Talhah ('aaqadat)}}
\hadithdefcmd{abudawud}{2924}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَلِيُّ بْنُ حُسَيْنٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، وَالَّذِينَ، آمَنُوا وَهَاجَرُوا وَالَّذِينَ آمَنُوا وَلَمْ يُهَاجِرُوا فَكَانَ الأَعْرَابِيُّ لاَ يَرِثُ الْمُهَاجِرَ وَلاَ يَرِثُهُ الْمُهَاجِرُ فَنَسَخَتْهَا فَقَالَ ‏\{‏ وَأُولُو الأَرْحَامِ بَعْضُهُمْ أَوْلَى بِبَعْضٍ ‏\}‏\hadithno{2924}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Abbas:Referring to the verse: "Those who believed and adopted exile... As to those who believed but came not into exile": A bedouin (who did not migrate to Medina) did not inherit from an emigrant, and an emigrant did no inherit from him. It was abrogated by the verse: "But kindred by blood have prior rights against each other}}
\hadithdefcmd{abudawud}{2925}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، وَابْنُ، نُمَيْرٍ وَأَبُو أُسَامَةَ عَنْ زَكَرِيَّا، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِيهِ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ حِلْفَ فِي الإِسْلاَمِ وَأَيُّمَا حِلْفٍ كَانَ فِي الْجَاهِلِيَّةِ لَمْ يَزِدْهُ الإِسْلاَمُ إِلاَّ شِدَّةً ‏"‏ ‏.‏\hadithno{2925}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2530)}\hadithtrans{Narrated Jubair b. Mu'tim:The Messenger of Allah (ﷺ) as saying: There is no alliance in Islam, and Islam strengthened the alliance made during pre-Islamic days}}
\hadithdefcmd{abudawud}{2926}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ الأَحْوَلِ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ حَالَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ الْمُهَاجِرِينَ وَالأَنْصَارِ فِي دَارِنَا ‏.‏ فَقِيلَ لَهُ أَلَيْسَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ حِلْفَ فِي الإِسْلاَمِ ‏"‏ ‏.‏ فَقَالَ حَالَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ الْمُهَاجِرِينَ وَالأَنْصَارِ فِي دَارِنَا ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا\hadithno{2926}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{Narrated Anas bin Malik:The Messenger of Allah (ﷺ) established an alliance (of brotherhood) between the Emigrants and the Helpers in our house. He was asked: Did not the Messenger of Allah (ﷺ) say: There is no alliance in Islam ? He replied: The Messenger of Allah (ﷺ) established an alliance between the Emigrants and the Helpers in our house. This he said twice or thrice}}
\hadithdefcmd{abudawud}{2927}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، قَالَ كَانَ عُمَرُ بْنُ الْخَطَّابِ يَقُولُ الدِّيَةُ لِلْعَاقِلَةِ وَلاَ تَرِثُ الْمَرْأَةُ مِنْ دِيَةِ زَوْجِهَا شَيْئًا حَتَّى قَالَ لَهُ الضَّحَّاكُ بْنُ سُفْيَانَ كَتَبَ إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أُوَرِّثَ امْرَأَةَ أَشْيَمَ الضِّبَابِيِّ مِنْ دِيَةِ زَوْجِهَا ‏.‏ فَرَجَعَ عُمَرُ ‏.‏ قَالَ أَحْمَدُ بْنُ صَالِحٍ حَدَّثَنَا عَبْدُ الرَّزَّاقِ بِهَذَا الْحَدِيثِ عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ عَنْ سَعِيدٍ وَقَالَ فِيهِ وَكَانَ النَّبِيُّ صلى الله عليه وسلم اسْتَعْمَلَهُ عَلَى الأَعْرَابِ ‏.‏\hadithno{2927}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Umar ibn al-Khattab: Sa'id said: Umar ibn al-Khattab said: Blood-money is meant for the clan of the slain, and she will not inherit from the blood-money of her husband. Ad-Dahhak ibn Sufyan said: The Messenger of Allah (ﷺ) wrote to me that I should give a share to the wife of Ashyam ad-Dubabi from the blood-money of her husband. So Umar withdrew his opinion. Ahmad ibn Salih said: AbdurRazzaq transmitted this tradition to us from Ma'mar, from az-Zuhri on the authority of Sa'id. In this version he said: The Prophet (ﷺ) made him governor over the bedouins}}
